@@ -13,10 +13,12 @@ package Rex::Cloud::Amazon;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.4.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Cloud::Base;
+use AWS::Signature4;
+use HTTP::Request::Common;
 
 use base qw(Rex::Cloud::Base);
 
@@ -50,6 +52,14 @@ sub new {
   return $self;
 }
 
+sub signer {
+  my ($self) = @_;
+  return AWS::Signature4->new(
+    -access_key => $self->{__access_key},
+    -secret_key => $self->{__secret_access_key}
+  );
+}
+
 sub set_auth {
   my ( $self, $access_key, $secret_access_key ) = @_;
 
@@ -419,7 +429,11 @@ sub _request {
   Rex::Logger::debug( "Sending request to: https://" . $self->{'__endpoint'} );
   Rex::Logger::debug( "  $_ -> " . $param{$_} ) for keys %param;
 
-  my $res = $ua->post( "https://" . $self->{'__endpoint'}, \%param );
+  my $req = POST( "https://" . $self->{__endpoint}, [%param] );
+  $self->signer->sign($req);
+
+  #my $res = $ua->post( "https://" . $self->{'__endpoint'}, \%param );
+  my $res = $ua->request($req);
 
   if ( $res->code >= 500 ) {
     Rex::Logger::info( "Error on request", "warn" );
@@ -451,6 +465,11 @@ sub _sign {
     $args{$key} = $o_args{$key};
   }
 
+  $args{Action}  = $action;
+  $args{Version} = $self->{__version};
+
+  return %args;
+
   my %sign_hash = (
     AWSAccessKeyId   => $self->{"__access_key"},
     Action           => $action,
