@@ -14,20 +14,20 @@ With this module you can manipulate files.
 
 =head1 SYNOPSIS
 
- task "read-passwd", "server01", sub {
+ task "read_passwd", "server01", sub {
    my $fh = file_read "/etc/passwd";
-   for my $line = ($fh->read_all) {
+   for my $line ($fh->read_all) {
      print $line;
    }
    $fh->close;
  };
  
- task "read-passwd2", "server01", sub {
+ task "read_passwd2", "server01", sub {
    say cat "/etc/passwd";
  };
 
 
- task "write-passwd", "server01", sub {
+ task "write_passwd", "server01", sub {
    my $fh = file_write "/etc/passwd";
    $fh->write("root:*:0:0:root user:/root:/bin/sh\n");
    $fh->close;
@@ -62,7 +62,7 @@ use strict;
 use warnings;
 use Fcntl;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.4.1'; # VERSION
 
 require Rex::Exporter;
 use Data::Dumper;
@@ -177,7 +177,8 @@ sub template {
       $content = eval { local ( @ARGV, $/ ) = ($file); <>; };
     }
     elsif ( $file =~ m/^\@/ ) {
-      my @caller    = caller(0);
+      my @caller = caller(0);
+
       my $file_path = Rex::get_module_path( $caller[0] );
 
       if ( !-f $file_path ) {
@@ -194,7 +195,11 @@ sub template {
         elsif ( -f $caller[1] ) {
           $file_path = $caller[1];
         }
+        elsif ( $caller[1] =~ m|^/loader/[^/]+/__Rexfile__.pm$| ) {
+          $file_path = $INC{"__Rexfile__.pm"};
+        }
       }
+
       my $file_content = eval { local ( @ARGV, $/ ) = ($file_path); <>; };
       my ($data) = ( $file_content =~ m/.*__DATA__(.*)/ms );
       my $fp = Rex::File::Parser::Data->new( data => [ split( /\n/, $data ) ] );
@@ -290,6 +295,19 @@ This function is the successor of I<install file>. Please use this function to u
  
  };
 
+The first parameter is either a string or an array reference. In the latter case the
+function is called for all strings in the array. Therefore, the following constructs 
+are equivalent:
+
+  file '/tmp/test1', ensure => 'directory';
+  file '/tmp/test2', ensure => 'directory';
+
+  file [ qw( /tmp/test1 /tmp/test2 ) ], ensure => 'directory'; # use array ref
+
+  file [ glob('/tmp/test{1,2}') ], ensure => 'directory'; # explicit glob call for array contents
+
+Use the glob carefully as B<it can leak local filesystem information> (e.g. when using wildcards).
+
 The I<source> is subject to a path resolution algorithm. This algorithm
 can be configured using the I<set> function to set the value of the
 I<path_map> variable to a hash containing path prefixes as its keys.
