@@ -9,7 +9,7 @@ package Rex::Interface::Fs::SSH;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.4.1'; # VERSION
 
 use Rex::Helper::File::Stat;
 use Rex::Helper::Encode;
@@ -138,7 +138,8 @@ sub stat {
 
   if ( !%ret ) { return undef; }
 
-  $ret{'mode'} = sprintf( "%04o", $ret{'mode'} & 07777 );
+  $ret{'mode'} =
+    sprintf( "%04o", Rex::Helper::File::Stat->S_IMODE( $ret{'mode'} ) );
 
   Rex::Commands::profiler()->end("stat: $file");
 
