@@ -9,7 +9,7 @@ package Rex::Interface::Shell::Ksh;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.4.1'; # VERSION
 
 use Rex::Interface::Shell::Bash;
 
@@ -25,15 +25,4 @@ sub new {
   return $self;
 }
 
-sub detect {
-  my ( $self, $con ) = @_;
-
-  my ($shell_path) = $con->_exec("echo \$SHELL");
-  if ( $shell_path =~ m/\/ksh$/ ) {
-    return 1;
-  }
-
-  return 0;
-}
-
 1;
