@@ -9,7 +9,7 @@ package Rex::Virtualization::LibVirt::guestinfo;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.4.1'; # VERSION
 
 use Data::Dumper;
 use Rex::Logger;
@@ -21,6 +21,7 @@ use Rex::Virtualization::LibVirt::info;
 use Rex::Interface::File;
 use Rex::Interface::Exec;
 use JSON::XS;
+require Rex::Commands::Run;
 
 sub execute {
   my ( $class, $vmname ) = @_;
@@ -132,7 +133,11 @@ sub execute {
 
     my $got_ip = 0;
 
-    my $command = operating_system_is("Gentoo") ? '/sbin/arp' : '/usr/sbin/arp';
+    # search arp in different locations.
+    # sometimes there is not PATH for normal users to /sbin commands.
+    # and also arp can be in different locations.
+    my $command =
+      Rex::Commands::Run::can_run( "/sbin/arp", "/usr/sbin/arp", "arp" );
 
     while ( $got_ip < scalar( keys %{$ifs} ) ) {
       my %arp =
